==> VE-SDK-0.5.0.zip: org/eclipse/ve/internal/cde/emf/DefaultGraphicalEditPartFactory.java <==
package org.eclipse.ve.internal.cde.emf;
/*******************************************************************************
 * Copyright (c) 2001, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
/*
 *  $RCSfile: DefaultGraphicalEditPartFactory.java,v $
 *  $Revision: 1.1 $  $Date: 2003/10/27 17:37:07 $ 
 */

import org.eclipse.emf.ecore.EObject;

import org.eclipse.gef.EditPart;
/**
 * Default factory for creating GraphicalEditParts.
 * It gets the class string out of the decorator of the RefObject and
 * uses the graphviewClassname attribute.
 */
public class DefaultGraphicalEditPartFactory extends AbstractEditPartFactory {

	protected ClassDescriptorDecoratorPolicy policy;

	public DefaultGraphicalEditPartFactory(ClassDescriptorDecoratorPolicy policy) {
		this.policy = policy;
	}

	public EditPart createEditPart(EditPart parentEP, Object modelObject) {
		String epClassString = modelObject instanceof EObject ? policy.getGraphViewClassname(((EObject) modelObject).eClass()) : "org.eclipse.ve.internal.cde.core:org.eclipse.ve.internal.cde.core.CDEDefaultGraphicalEditPart";
		return createEditPart(epClassString, modelObject);
	}
}

==> VE-SDK-1.0.2.2.zip: org/eclipse/ve/internal/cde/emf/DefaultGraphicalEditPartFactory.java <==
/*******************************************************************************
 * Copyright (c) 2001, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ve.internal.cde.emf;
/*
 *  $RCSfile: DefaultGraphicalEditPartFactory.java,v $
 *  $Revision: 1.3 $  $Date: 2004/08/27 15:35:35 $ 
 */

import org.eclipse.emf.ecore.EObject;

import org.eclipse.gef.EditPart;
/**
 * Default factory for creating GraphicalEditParts.
 * It gets the class string out of the decorator of the RefObject and
 * uses the graphviewClassname attribute.
 */
public class DefaultGraphicalEditPartFactory extends AbstractEditPartFactory {

	protected ClassDescriptorDecoratorPolicy policy;

	public DefaultGraphicalEditPartFactory(ClassDescriptorDecoratorPolicy policy) {
		this.policy = policy;
	}

	public EditPart createEditPart(EditPart parentEP, Object modelObject) {
		String epClassString = modelObject instanceof EObject ? policy.getGraphViewClassname(((EObject) modelObject).eClass()) : "org.eclipse.ve.internal.cde.core:org.eclipse.ve.internal.cde.core.CDEDefaultGraphicalEditPart"; //$NON-NLS-1$
		return createEditPart(epClassString, modelObject);
	}
}
